import sys, clr 

clr.AddReference("System.Drawing") 				
clr.AddReference("System.Windows.Forms")

# Add a reference to the APx API		
clr.AddReference(r"C:\Program Files\Audio Precision\APx500 6.0\API\AudioPrecision.API2.dll") 	
clr.AddReference(r"C:\Program Files\Audio Precision\APx500 6.0\API\AudioPrecision.API.dll") 

from AudioPrecision.API import *
from System.Drawing import Point
from System.Windows.Forms import Application, Button, Form, Label
from System.IO import Directory, Path

class Container(Form):

    def __init__(self): # Create a form with a label and four buttons
        self.Text = 'APx Python Example'
        self.Height = 220
        self.Width = 200
        
        self.label = Label()
        self.label.Text = "Python APx Control"
        self.label.Location = Point(20, 20)
        self.label.Height = 20
        self.label.Width = 200

        self.count = 0

        bLoad = Button()
        bLoad.Text = "Load APx Software"
        bLoad.Location = Point(20, 50)
        bLoad.Width = 150
        bLoad.Click += self.APxLoad

        bProj = Button()
        bProj.Text = "Open Sample Project"
        bProj.Location = Point(20, 80)
        bProj.Width = 150
        bProj.Click += self.APxProject

        bMeas = Button()
        bMeas.Text = "Run Sequence..."
        bMeas.Location = Point(20, 110)
        bMeas.Width = 150
        bMeas.Click += self.APxMeasurement

        bData = Button()
        bData.Text = "Get Data"
        bData.Location = Point(20, 140)
        bData.Width = 150
        bData.Click += self.APxGetData

        self.Controls.Add(self.label)
        self.Controls.Add(bLoad)
        self.Controls.Add(bProj)
        self.Controls.Add(bMeas)	
        self.Controls.Add(bData)	

    def APxLoad(self, sender, args): # Initialize the software and set it to Visible
        APx = APx500_Application()
        APx.Visible = 1
    
    def APxProject(self, sender, args): # Load the example project file
        filename = "SampleProject.approjx"
        directory = Directory.GetCurrentDirectory()
        fullpath = Path.Combine(directory, filename)
        APx = APx500_Application()
        APx.OpenProject(fullpath)
    
    def APxMeasurement(self, sender, args): # Run the sequence, which will run the Frequency Response measurement
        APx = APx500_Application()
        APx.Sequence.Run()
      
    def APxGetData(self, sender, args): # Get results acquired in the last sequence run
        APx = APx500_Application()

        # Get Frequency Response RMS Level XY values by result name (string)
        xvalues = APx.Sequence[0]["Frequency Response"].SequenceResults["RMS Level"].GetXValues(InputChannelIndex.Ch1, VerticalAxis.Left, SourceDataType.Measured, 1)
        yvalues = APx.Sequence[0]["Frequency Response"].SequenceResults["RMS Level"].GetYValues(InputChannelIndex.Ch1, VerticalAxis.Left, SourceDataType.Measured, 1)

         # Get Frequency Response Gain XY values by result type
        xvalues = APx.Sequence[0]["Frequency Response"].SequenceResults[MeasurementResultType.GainVsFrequency].GetXValues(InputChannelIndex.Ch1, VerticalAxis.Left, SourceDataType.Measured, 1)
        yvalues = APx.Sequence[0]["Frequency Response"].SequenceResults[MeasurementResultType.GainVsFrequency].GetYValues(InputChannelIndex.Ch1, VerticalAxis.Left, SourceDataType.Measured, 1)

form = Container()
Application.Run(form)